==> jc-1.4.0.tar.gz: gnu/java/net/BASE64.h <==
// public final class gnu.java.net.BASE64

// class file dependencies
// @dep_class 5e55d3dfc758ed38 gnu_java_net_BASE64
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_BASE64_H_
#define _JC_gnu_java_net_BASE64_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_BASE64$sub_refs	_jc_gnu_java_net_BASE64$sub_refs;
typedef struct _jc_gnu_java_net_BASE64$sub_nonrefs	_jc_gnu_java_net_BASE64$sub_nonrefs;
typedef struct _jc_gnu_java_net_BASE64$refs	_jc_gnu_java_net_BASE64$refs;
typedef struct _jc_gnu_java_net_BASE64$nonrefs	_jc_gnu_java_net_BASE64$nonrefs;
typedef struct _jc_gnu_java_net_BASE64$object	_jc_gnu_java_net_BASE64$object;

typedef struct _jc_gnu_java_net_BASE64$fields_struct	_jc_gnu_java_net_BASE64$fields_struct;
typedef const struct _jc_gnu_java_net_BASE64$vmethods	_jc_gnu_java_net_BASE64$vmethods;
typedef const struct _jc_gnu_java_net_BASE64$vtable	_jc_gnu_java_net_BASE64$vtable;
typedef const struct _jc_gnu_java_net_BASE64$vtype	_jc_gnu_java_net_BASE64$vtype;

// Class fields structure
struct _jc_gnu_java_net_BASE64$fields_struct {
	_jc_byte_array	*dst;
	_jc_byte_array	*src;
};
extern _jc_gnu_java_net_BASE64$fields_struct _jc_gnu_java_net_BASE64$class_fields;

// Constructors
extern void _jc_gnu_java_net_BASE64$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_BASE64$object *);

// Static methods
extern void _jc_gnu_java_net_BASE64$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern _jc_byte_array *_jc_gnu_java_net_BASE64$method$decode$9620a3abb2d6673a(_jc_env *, struct _jc_byte_array *);
extern _jc_byte_array *_jc_gnu_java_net_BASE64$method$encode$f0cea48c79a55bfd(_jc_env *, struct _jc_byte_array *);
extern void _jc_gnu_java_net_BASE64$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_gnu_java_net_BASE64$vmethods {
};

// Vtable
struct _jc_gnu_java_net_BASE64$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_BASE64$vmethods	gnu_java_net_BASE64;
};

// Vtype
struct _jc_gnu_java_net_BASE64$vtype {
	_jc_type			type;
	_jc_gnu_java_net_BASE64$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_BASE64$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_BASE64$refs {
    _jc_gnu_java_net_BASE64$sub_refs	gnu_java_net_BASE64;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_BASE64$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_BASE64$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_BASE64$sub_nonrefs	gnu_java_net_BASE64;
};

// Object instance structure
struct _jc_gnu_java_net_BASE64$object {
	_jc_gnu_java_net_BASE64$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_BASE64$vtype	*vtype;
	_jc_gnu_java_net_BASE64$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_BASE64$vtype _jc_gnu_java_net_BASE64$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_BASE64, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_BASE64$class_object;

#endif	/* _JC_gnu_java_net_BASE64_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/BASE64.h <==
// public final class gnu.java.net.BASE64

// class file dependencies
// @dep_class 5e55d3dfc758ed38 gnu_java_net_BASE64
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_BASE64_H_
#define _JC_gnu_java_net_BASE64_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_BASE64$sub_refs	_jc_gnu_java_net_BASE64$sub_refs;
typedef struct _jc_gnu_java_net_BASE64$sub_nonrefs	_jc_gnu_java_net_BASE64$sub_nonrefs;
typedef struct _jc_gnu_java_net_BASE64$refs	_jc_gnu_java_net_BASE64$refs;
typedef struct _jc_gnu_java_net_BASE64$nonrefs	_jc_gnu_java_net_BASE64$nonrefs;
typedef struct _jc_gnu_java_net_BASE64$object	_jc_gnu_java_net_BASE64$object;

typedef struct _jc_gnu_java_net_BASE64$fields_struct	_jc_gnu_java_net_BASE64$fields_struct;
typedef const struct _jc_gnu_java_net_BASE64$vmethods	_jc_gnu_java_net_BASE64$vmethods;
typedef const struct _jc_gnu_java_net_BASE64$vtable	_jc_gnu_java_net_BASE64$vtable;
typedef const struct _jc_gnu_java_net_BASE64$vtype	_jc_gnu_java_net_BASE64$vtype;

// Class fields structure
struct _jc_gnu_java_net_BASE64$fields_struct {
	_jc_byte_array	*dst;
	_jc_byte_array	*src;
};
extern _jc_gnu_java_net_BASE64$fields_struct _jc_gnu_java_net_BASE64$class_fields;

// Constructors
extern void _jc_gnu_java_net_BASE64$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_BASE64$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_net_BASE64$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_net_BASE64$method$decode$9620a3abb2d6673a(_jc_env *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_net_BASE64$method$encode$f0cea48c79a55bfd(_jc_env *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_BASE64$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_net_BASE64$vmethods {
};

// Vtable
struct _jc_gnu_java_net_BASE64$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_BASE64$vmethods	gnu_java_net_BASE64;
};

// Vtype
struct _jc_gnu_java_net_BASE64$vtype {
	_jc_type			type;
	_jc_gnu_java_net_BASE64$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_BASE64$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_BASE64$refs {
    _jc_gnu_java_net_BASE64$sub_refs	gnu_java_net_BASE64;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_BASE64$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_BASE64$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_BASE64$sub_nonrefs	gnu_java_net_BASE64;
};

// Object instance structure
struct _jc_gnu_java_net_BASE64$object {
	_jc_gnu_java_net_BASE64$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_BASE64$vtype	*vtype;
	_jc_gnu_java_net_BASE64$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_BASE64$vtype _jc_gnu_java_net_BASE64$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_BASE64, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_BASE64$class_object;

#endif	/* _JC_gnu_java_net_BASE64_H_ */
